<?php

namespace Negundo\Client\Task;

class TaskReport
{
    protected array $events = [];

    public function __construct(
        public string|array $message,
        public string $title,
        public ? StatusEnum $status = null,
        public array $data = [],
    ) {}

    public function addData(string $name, array $data) : static
    {
        $this->data[$name][] = $data;

        return $this;
    }

    public function addEvent(string $key, ? StatusEnum $status = null, array $data) : static
    {
        $this->events[] = [
            'key' => $key,
            'status' => $status ? $status->value : null,
            'data' => $data
        ];

        return $this;
    }

    public function addMessage(string $message) : static
    {
        if ( is_string($this->message) ) {
            $this->message = [
                $this->message, $message
            ];
        }
        else {
            $this->message[] = $message;
        }

        return $this;
    }

    public function getMessage() : string
    {
        return implode(PHP_EOL, (array) $this->message);
    }

    public function getTitle() : string
    {
        return $this->title;
    }

    public function getData() : array
    {
        return $this->data;
    }

    public function getEvents() : array
    {
        return $this->events;
    }

    public function getStatus() : StatusEnum
    {
        return $this->status;
    }
}